diff --git src/wp-includes/functions.php src/wp-includes/functions.php
index 966dcd8..eea755f 100644
--- src/wp-includes/functions.php
+++ src/wp-includes/functions.php
@@ -5113,16 +5113,16 @@
  * @since 3.4.0
  * @access private
  *
  * @param array  $object_ids ID list.
  * @param string $cache_key  The cache bucket to check against.
  *
  * @return array List of ids not present in the cache.
  */
-function _get_non_cached_ids( $object_ids, $cache_key ) {
+function _get_non_cached_ids( $object_ids, $cache_group ) {
 	$clean = array();
 	foreach ( $object_ids as $id ) {
 		$id = (int) $id;
-		if ( !wp_cache_get( $id, $cache_key ) ) {
+		if ( !wp_cache_get( $id, $cache_group ) ) {
 			$clean[] = $id;
 		}
 	}
@@ -5113,16 +5113,16 @@
  * @access private
  *
- * @param array  $object_ids ID list.
- * @param string $cache_key  The cache bucket to check against.
+ * @param array  $object_ids  ID list.
+ * @param string $cache_group The cache group to check against.
  *
  * @return array List of ids not present in the cache.
